@@ -577,7 +577,8 @@ class ModelsEndpointGroup(EndpointGroup[data_model.ModelInfo]):
         Returns:
             data_model.ModelInfo: _description_
         """
-        if project_id:
+        
+        if project_id and "/" not in model_name:
             return self._call_endpoint("GET", f"projects/{project_id}/models/{model_name}")
         else:
             if "/" in model_name:
@@ -733,6 +734,7 @@ class TopicsEndpointGroup(EndpointGroup[data_model.Topic]):
         while True:
             subresults = self._call_endpoint("GET", f"/projects/{project_id}/topic/search", query_params={"skip":page_size*page,"take":page_size})
             results+=subresults
+            page+=1
             if not subresults:
                 break
         return results
